@@ -1,13 +1,14 @@
 #' Show the methods for calculating a noise threshold
 #' @description This function outputs the methods available for the calculation of
-#' the noise threshold. To be used as input in calculate_threshold_noise().
-#' @return A character vector of options for the method arguement of calculate_threshold_noise()
+#' the noise threshold. To be used as input in \code{\link{calculate_noise_threshold}}.
+#' @return A character vector of options for the method.chosen arguement of
+#' \code{\link{calculate_noise_threshold}}
 #' @export
 #' @examples get_methods_calculate_noise_threshold()
 get_methods_calculate_noise_threshold = function(){
-  approaches <- base::c(base::rep("Density_based_fixed_threshold", 3),
+  approaches <- base::c(base::rep("Density_based", 3),
                         base::rep("Line_plot", 4),
-                        base::rep("Boxplot", 2))
+                        base::rep("Boxplot", 3))
   methods <- base::c("No_normalisation",
                      "RPM_normalisation",
                      "Quantile_normalisation",
@@ -16,7 +17,8 @@ get_methods_calculate_noise_threshold = function(){
                      "loess25_smoothing",
                      "loess50_smoothing",
                      "Median",
-                     "IQR")
+                     "IQR",
+                     "Quant5")
   vec <- base::paste(approaches, methods, sep="-")
   return(vec)
 }
